==> pot-3.1.0.src.tar.gz: pot-3.1/console.c <==
/*
pot 2 est un programme servant  lister vos "pot" sur un rseau
Copyright (C) 2001 Fabien Carrion et Guillaume Pinot

Ce programme est libre, vous pouvez le redistribuer et/ou le modifier selon les
termes de la Licence Publique Gnrale GNU publie par la Free Software
Foundation (version 2).

Ce programme est distribu car potentiellement utile, mais SANS AUCUNE GARANTIE,
ni explicite ni implicite, y compris les garanties de commercialisation ou
d'adaptation dans un but spcifique. Reportez-vous  la Licence Publique
Gnrale GNU pour plus de dtails.

Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en mme
temps que ce programme ; si ce n'est pas le cas, crivez  la Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, tats-Unis.

fcarrion@etu.utc.fr
pinotgui@etu.utc.fr
*/

#include "commun.h"
#include "console.h"

void console ( char *chemin )
{
  int tmp;
  int compteur;
  
  char talk;
  
  /* scanne localhost */
  tmp = finger( chemin );
  if ( tmp < 0 )
    return;
  
  compteur = tmp;
  
#ifdef SAMBA
  /* initialisation de la structure avant de lancer samba */
  connecte = &depart;

  /* scanne samba (PC) */
  tmp = samba ( chemin );
  if ( tmp < 0 )
    return;
  
  compteur = compteur + tmp;
#endif

  /* initialisation de la structure */
  connecte = &depart;

  if ( compteur > 0 )
    {
      printf("\033[50;42mLogin    Talk \033[50;43m   Nom                  \033[50;41mSalle          \033[0m\n");
      
      while ( (connecte = connecte->next) )
	{
	  /* peut-on talker la personne */
	  if ( connecte->talk )
	    talk = '+';
	  else
	    talk = '-';
 
	  printf ("%-8.8s  %c   %-23.23s %-15s\n", connecte->login , talk , connecte->nom , connecte->salle );
	}
    }
  else
    {
      printf ("Pas de \"pot\" trouv.\n");
    }
}

==> pot-3.1.2.src.tar.gz: pot-3.1/console.c <==
/*
pot 2 est un programme servant  lister vos "pot" sur un rseau
Copyright (C) 2001 Fabien Carrion et Guillaume Pinot

Ce programme est libre, vous pouvez le redistribuer et/ou le modifier selon les
termes de la Licence Publique Gnrale GNU publie par la Free Software
Foundation (version 2).

Ce programme est distribu car potentiellement utile, mais SANS AUCUNE GARANTIE,
ni explicite ni implicite, y compris les garanties de commercialisation ou
d'adaptation dans un but spcifique. Reportez-vous  la Licence Publique
Gnrale GNU pour plus de dtails.

Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en mme
temps que ce programme ; si ce n'est pas le cas, crivez  la Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, tats-Unis.

fcarrion@etu.utc.fr
pinotgui@etu.utc.fr
*/

#include "commun.h"
#include "console.h"

void console ( char *chemin ,int couleur)
{
  int tmp;
  int compteur;
  
  char talk;
  
  /* scanne localhost */
  tmp = finger( chemin );
  if ( tmp < 0 )
    return;
  
  compteur = tmp;
  
#ifdef SAMBA
  /* initialisation de la structure avant de lancer samba */
  connecte = &depart;

  /* scanne samba (PC) */
  tmp = samba ( chemin );
  if ( tmp < 0 )
    return;
  
  compteur = compteur + tmp;
#endif

  /* initialisation de la structure */
  connecte = &depart;

  if ( compteur > 0 )
    {
      if ( couleur == 1 )
	printf("\033[50;42mLogin    Talk \033[50;43m   Nom                  \033[50;41mSalle          \033[0m\n");
      else
	printf("Login    Talk    Nom                  Salle          \n");

      while ( (connecte = connecte->next) )
	{
	  /* peut-on talker la personne */
	  if ( connecte->talk )
	    talk = '+';
	  else
	    talk = '-';
 
	  printf ("%-8.8s  %c   %-23.23s %-15s\n", connecte->login , talk , connecte->nom , connecte->salle );
	}
    }
  else
    {
      printf ("Pas de \"pot\" trouv.\n");
    }
}
